#
# Apollo-fishing.R,  9 Feb 25
#
# Data from:
# A MODEL OF THE COST OF SOFTWARE DEVELOPMENT FOR THE APOLLO SPACECRAFT COMPUTER
# DANIEL ALLEN RANKIN

library("colorspace")

par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)

Apollo_launch=function(Apollo_str)
{
Apollo_x=subset(ai, APOLLO_MISSION == Apollo_str)
Apollo_x=Apollo_x[nrow(Apollo_x), ] # Get the latest

text(Apollo_x$date, Apollo_x$CUM_NEW_WORDS, Apollo_str, cex=1.1)
}

cu=read.csv("comp-usage.csv")

ac=read.csv("Apollo-costs.csv")
ac$date=as.Date(ac$PERIOD, format="%d/%m/%Y")

ai=read.csv("Apollo-instr.csv")
ai$date=as.Date(paste0("1/", ai$MONTH.YEAR), format="%d/%m/%Y")

# sort(colSums(ac[, 2:17], na.rm=TRUE), decreasing=TRUE)
#
#  Digital_Computer           Testing            Coding 
#             18373              9786              8233 
#  Hybrid_Computer          Analysis     Documentation        Management 
#             7190              6580              4177              2654 

pal_col=rainbow(7)

plot(ac$date, ac$Digital_Computer, type="l", col=pal_col[2], lwd=1.4,
	yaxs="i",
	ylim=c(0, 2500),
	xlab="Date", ylab="Thousand dollars")
lines(ac$date, ac$Analysis, col=pal_col[3], lwd=1.4)
lines(ac$date, ac$Coding, col=pal_col[1], lwd=1.4)
lines(ac$date, ac$Testing, col=pal_col[4], lwd=1.4)
lines(ac$date, ac$Hybrid_Computer, col=pal_col[5], lwd=1.4)
lines(ac$date, ac$Documentation, col=pal_col[6], lwd=1.4)
lines(ac$date, ac$Management, col=pal_col[7], lwd=1.4)


legend("topleft", legend=c("Digital computing", "Testing",
				"Coding", "Hybrid computing", "Analysis", "Documentation", "Management"),
                        fill=pal_col[c(2, 4, 1, 5, 3, 6, 7)], border="white", bty="n")

dev.copy(dev=png, file="Apollo-activity-cost.png")
dev.off()



pal_col=rainbow(2)

plot(ai$date, ai$CUM_NEW_WORDS, type="l", log="y", col=pal_col[2],
	xlab="Date", ylab="Words")
lines(ai$date, ai$TOTAL_WORDS, col=pal_col[1])

fixed_mem=36864
changeable_mem=2048
lines(range(ai$date), rep(fixed_mem, 2), col="grey")
lines(range(ai$date), rep(fixed_mem+2*changeable_mem, 2), col="grey")
text(max(ai$date), fixed_mem, fixed_mem, adj=c(1, 1))
text(max(ai$date), fixed_mem+2*changeable_mem, fixed_mem+2*changeable_mem, adj=c(1, 0))

Apollo_launch("8")
Apollo_launch("9")
# Apollo_launch("10")
Apollo_launch("11")
Apollo_launch("12")
Apollo_launch("13")
Apollo_launch("14")

legend("topleft", legend=c("Written instruction words", "Shipped instruction words"),
                        fill=pal_col[c(2, 1)], border="white", bty="n")

dev.copy(dev=png, file="Apollo-instructions.png")
dev.off()

# 1961.97 H-800 Delivery
# 1962.41 H-800 Production
# 1963.95 H-800 Removed
# 1963.95 H-1800 1 Delivery
# 1964.28 H-1800 1 Production
# 1966.15 H-1800 2 Delivery/Production
# 1967.91 H-1800 2 Removal
# 1968.24 H-1800 1 Removal
# 1966.7 IBM 360/75 1 Delivery
# 1967.69 IBM 360/75 1 Production
# 1968.35 IBM 360/75 2 Delivery/production
# 1969.67 IBM 360/75 2 Removal

plot(cu$Date, cu$Computer_usage, log="y", type="l", col="salmon", lwd=1.4,
	xlab="Date", ylab="Computer usage (hours per month)")

